import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class AbsurdNotions(BasicComicModule):
    latestUrl = 'http://www.absurdnotions.org/'
    imageUrl = 'http://www.absurdnotions.org/page%s.html'
    imageSearch = re.compile(r'<IMG SRC="(an\d+.?\..+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<A.*?HREF="(page\d+\.html)"><img SRC="nprev\.gif"', re.IGNORECASE | re.DOTALL)
    help = 'Index format: n (unpadded)'
